==> git-extras_1.9.0.orig.tar.gz: git-extras-1.9.0/man/git-info.md <==
git-info(1) -- Returns information on current repository
================================

## SYNOPSIS

`git-info`

## DESCRIPTION

Shows the following information about a repository:

 1. Remote Url(s)
 2. Remote Branches
 3. Local Branches
 4. Most recent commit
 5. Configuration Info

## OPTIONS

N/A

## EXAMPLES

Outputs info about a repo:

    $ git info

    ## Remote URLs:

    origin		git@github.com:sampleAuthor/git-extras.git (fetch)
    origin		git@github.com:sampleAuthor/git-extras.git (push)

    ## Remote Branches:

    origin/HEAD -> origin/master
    origin/myBranch

    ## Local Branches:

    myBranch
    * master

    ## Most Recent Commit:

    commit e3952df2c172c6f3eb533d8d0b1a6c77250769a7
    Author: Sample Author <sampleAuthor@gmail.com>

    Added git-info command.

    Type 'git log' for more commits, or 'git show <commit id>' for full commit details.

    ## Configuration (.git/config):

    color.diff=auto
    color.status=auto
    color.branch=auto
    user.name=Sample Author
    user.email=sampleAuthor@gmail.com
    core.repositoryformatversion=0
    core.filemode=true
    core.bare=false
    core.logallrefupdates=true
    core.ignorecase=true
    remote.origin.fetch=+refs/heads/*:refs/remotes/origin/*
    remote.origin.url=git@github.com:mub/git-extras.git
    branch.master.remote=origin
    branch.master.merge=refs/heads/master


## AUTHOR

Written by Leila Muhtasib &lt;<muhtasib@gmail.com>&gt;

## REPORTING BUGS

&lt;<https://github.com/visionmedia/git-extras/issues>&gt;

## SEE ALSO

&lt;<https://github.com/visionmedia/git-extras>&gt;

==> git-extras_5.1.0.orig.tar.gz: git-extras-5.1.0/man/git-info.md <==
git-info(1) -- Returns information on current repository
================================

## SYNOPSIS

`git-info`

## DESCRIPTION

Shows the following information about a repository:

 1. Remote Url(s)
 2. Remote Branches
 3. Local Branches
 4. Most recent commit
 5. Configuration Info

## OPTIONS

N/A

## EXAMPLES

Outputs info about a repo:

    $ git info

    ## Remote URLs:

    origin		git@github.com:sampleAuthor/git-extras.git (fetch)
    origin		git@github.com:sampleAuthor/git-extras.git (push)

    ## Remote Branches:

    origin/HEAD -> origin/master
    origin/myBranch

    ## Local Branches:

    myBranch
    * master

    ## Most Recent Commit:

    commit e3952df2c172c6f3eb533d8d0b1a6c77250769a7
    Author: Sample Author <sampleAuthor@gmail.com>

    Added git-info command.

    Type 'git log' for more commits, or 'git show <commit id>' for full commit details.

    ## Configuration (.git/config):

    color.diff=auto
    color.status=auto
    color.branch=auto
    user.name=Sample Author
    user.email=sampleAuthor@gmail.com
    core.repositoryformatversion=0
    core.filemode=true
    core.bare=false
    core.logallrefupdates=true
    core.ignorecase=true
    remote.origin.fetch=+refs/heads/*:refs/remotes/origin/*
    remote.origin.url=git@github.com:mub/git-extras.git
    branch.master.remote=origin
    branch.master.merge=refs/heads/master


## AUTHOR

Written by Leila Muhtasib &lt;<muhtasib@gmail.com>&gt;

## REPORTING BUGS

&lt;<https://github.com/tj/git-extras/issues>&gt;

## SEE ALSO

&lt;<https://github.com/tj/git-extras>&gt;
